# HG changeset patch
# User Yuriy Izorkin <lafiel@elven.pw>
# Date 1708074268 -10800
#      Fri Feb 16 12:04:28 2024 +0300
# Node ID 24be235c0a9c883718db1e54bf742bd9be782ee4
# Parent  89bff782528a91ad123b63b624f798e6fd9c8e68
MIME: change type image/x-ms-bmp to image/image

For .bmp files the image/bmp mime type is used according to IANA [1].

In Apache also uses this type [2]:
$ awk '/^image\/bmp/' mime.types
image/bmp                                       bmp

Extension usage statistics, according to httparhcive.org [3]:
$ awk 'NR==1||/^bmp,/' httparchive_exts.csv
ext,total_pages,total_requests
bmp,17013,37954
dib,22,28

The csv file was made with the following query:

SELECT
  ext,
  COUNT(distinct pageid) total_pages,
  COUNT(0) total_requests
FROM
  `httparchive.summary_requests.2024_01_01_desktop`
GROUP BY
  ext
ORDER BY
  total_requests DESC

Link for reference:

[1] https://www.iana.org/assignments/media-types/image/bmp
[2] https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types
[3] https://httparchive.org

diff -r 89bff782528a -r 24be235c0a9c conf/mime.types
--- a/conf/mime.types   Wed Feb 14 20:03:00 2024 +0400
+++ b/conf/mime.types   Fri Feb 16 12:04:28 2024 +0300
@@ -16,6 +16,7 @@
     text/x-component                                 htc;

     image/avif                                       avif;
+    image/bmp                                        bmp;
     image/png                                        png;
     image/svg+xml                                    svg svgz;
     image/tiff                                       tif tiff;
@@ -23,7 +24,6 @@
     image/webp                                       webp;
     image/x-icon                                     ico;
     image/x-jng                                      jng;
-    image/x-ms-bmp                                   bmp;

     font/woff                                        woff;
     font/woff2                                       woff2;
# HG changeset patch
# User Yuriy Izorkin
# Date 1708074518 -10800
#      Fri Feb 16 12:08:38 2024 +0300
# Node ID 94f80eface3b541d7b59d85fcc84d4acfca61e32
# Parent  24be235c0a9c883718db1e54bf742bd9be782ee4
MIME: update application/vnd.apple.mpegurl type

For .m3u and .m3u8 files the application/vnd.apple.mpegurl mime type
is used according to IANA [1].

In Apache also uses this extensions [2]:
$ awk '/m3u/' mime.types
application/vnd.apple.mpegurl                   m3u8
audio/x-mpegurl                                 m3u

There are practically no extensions in httparhcive.org statistics [3]:
$ awk 'NR==1||/^m3u,/||/^msu8,/' httparchive_exts.csv
ext,total_pages,total_requests
m3u,15,302

But these extensions are often used in various streaming services.

Link for reference:

[1] https://www.iana.org/assignments/media-types/application/vnd.apple.mpegurl
[2] https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types
[3] https://httparchive.org

diff -r 24be235c0a9c -r 94f80eface3b conf/mime.types
--- a/conf/mime.types   Fri Feb 16 12:04:28 2024 +0300
+++ b/conf/mime.types   Fri Feb 16 12:08:38 2024 +0300
@@ -35,7 +35,7 @@
     application/pdf                                  pdf;
     application/postscript                           ps eps ai;
     application/rtf                                  rtf;
-    application/vnd.apple.mpegurl                    m3u8;
+    application/vnd.apple.mpegurl                    m3u m3u8;
     application/vnd.google-earth.kml+xml             kml;
     application/vnd.google-earth.kmz                 kmz;
     application/vnd.ms-excel                         xls;
# HG changeset patch
# User Yuriy Izorkin
# Date 1708074976 -10800
#      Fri Feb 16 12:16:16 2024 +0300
# Node ID 400a32ebdb646c03c1837704eeed83b2135da0db
# Parent  94f80eface3b541d7b59d85fcc84d4acfca61e32
MIME: update application/vnd.ms-excel type

For .xls, .xlm, .xla, .xlc, .xlt and .xlw files the application/vnd.ms-excel
mime type according to MSDN blog [1]

In Apache also uses this extensions [2]:
$ awk '/xls xlm xla xlc xlt xlw/' mime.types
application/vnd.ms-excel                        xls xlm xla xlc xlt xlw

There are practically no extensions in httparhcive.org statistics [3]:
$ awk 'NR==1||/^xls,/||/^xlm,/||/^xla,/||/^xlc,/||/^xlt,/||/^xlw,/||/^eps3,/' httparchive_exts.csv
ext,total_pages,total_requests
xls,22,38
xlt,2,2

Link for reference:

[1] https://web.archive.org/web/20160215155254/http://blogs.msdn.com/b/vsofficedeveloper/archive/2008/05/08/office-2007-open-xml-mime-types.aspx
[2] https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types
[3] https://httparchive.org

diff -r 94f80eface3b -r 400a32ebdb64 conf/mime.types
--- a/conf/mime.types   Fri Feb 16 12:08:38 2024 +0300
+++ b/conf/mime.types   Fri Feb 16 12:16:16 2024 +0300
@@ -38,7 +38,7 @@
     application/vnd.apple.mpegurl                    m3u m3u8;
     application/vnd.google-earth.kml+xml             kml;
     application/vnd.google-earth.kmz                 kmz;
-    application/vnd.ms-excel                         xls;
+    application/vnd.ms-excel                         xls xlm xla xlc xlt xlw;
     application/vnd.ms-fontobject                    eot;
     application/vnd.ms-powerpoint                    ppt;
     application/vnd.oasis.opendocument.graphics      odg;
# HG changeset patch
# User Yuriy Izorkin
# Date 1708075032 -10800
#      Fri Feb 16 12:17:12 2024 +0300
# Node ID 8fd3313f33fab5a342a3d0bf8fa7ddd642ff76b8
# Parent  400a32ebdb646c03c1837704eeed83b2135da0db
MIME: update application/vnd.ms-powerpoint type

For .pot, .ppt and .pps files the application/vnd.ms-excel mime type
according to MSDN blog [1].

In Apache also uses this extensions [2]:
$ awk '/ppt pps pot/' mime.types
application/vnd.ms-powerpoint                   ppt pps pot

Extension usage statistics, according to httparhcive.org [3]:
$ awk 'NR==1||/^pot,/||/^ppt,/||/^pps,/' httparchive_exts.csv
ext,total_pages,total_requests
ppt,5,7
pot,4,5
pps,1,3

Link for reference:

[1] https://web.archive.org/web/20160215155254/http://blogs.msdn.com/b/vsofficedeveloper/archive/2008/05/08/office-2007-open-xml-mime-types.aspx
[2] https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types
[3] https://httparchive.org

diff -r 400a32ebdb64 -r 8fd3313f33fa conf/mime.types
--- a/conf/mime.types   Fri Feb 16 12:16:16 2024 +0300
+++ b/conf/mime.types   Fri Feb 16 12:17:12 2024 +0300
@@ -40,7 +40,7 @@
     application/vnd.google-earth.kmz                 kmz;
     application/vnd.ms-excel                         xls xlm xla xlc xlt xlw;
     application/vnd.ms-fontobject                    eot;
-    application/vnd.ms-powerpoint                    ppt;
+    application/vnd.ms-powerpoint                    pot ppt pps;
     application/vnd.oasis.opendocument.graphics      odg;
     application/vnd.oasis.opendocument.presentation  odp;
     application/vnd.oasis.opendocument.spreadsheet   ods;
# HG changeset patch
# User Yuriy Izorkin
# Date 1708075086 -10800
#      Fri Feb 16 12:18:06 2024 +0300
# Node ID f35143b87faea006b9d0dae731867dfa88eecbbd
# Parent  8fd3313f33fab5a342a3d0bf8fa7ddd642ff76b8
MIME: update application/vnd.wap.wmlc type

For .wmlc and .wbxml files the application/vnd.wap.wmlc mime type
according to IANA [1].

In Apache also uses this extensions [2]:
$ awk '/application\/vnd.wap.wbxml/||/application\/vnd.wap.wmlc/' mime.types
application/vnd.wap.wbxml                       wbxml
application/vnd.wap.wmlc                        wmlc

Link for reference:

[1] https://www.iana.org/assignments/media-types/application/vnd.wap.wmlc
[2] https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types

diff -r 8fd3313f33fa -r f35143b87fae conf/mime.types
--- a/conf/mime.types   Fri Feb 16 12:17:12 2024 +0300
+++ b/conf/mime.types   Fri Feb 16 12:18:06 2024 +0300
@@ -51,7 +51,7 @@
                                                      xlsx;
     application/vnd.openxmlformats-officedocument.wordprocessingml.document
                                                      docx;
-    application/vnd.wap.wmlc                         wmlc;
+    application/vnd.wap.wmlc                         wmlc wbxml;
     application/wasm                                 wasm;
     application/x-7z-compressed                      7z;
     application/x-cocoa                              cco;
